Table

Struct Table 

pub struct Table {
    pub rows: Vec<Vec<String>>,
    pub span: Span,
    pub position: LineCol,
}
A data table

Fields

rows: Vec<Vec<String>>

The rows of the data table. Each row is always the same length as the first row.

span: Span

The (start, end) offset the table directive was found in the .feature file.

position: LineCol

The (line, col) position the table directive was found in the .feature file.

Implementations

Source

impl Table

pub fn builder() -> TableBuilder<((), (), ())>

Create a builder for building Table. On the builder, call .rows(...), .span(...)(optional), .position(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of Table.

Source

impl Table

pub fn row_width(&self) -> usize