A data table
Fields
rows: Vec<Vec<String>>The rows of the data table. Each row is always the same length as the first row.
span: SpanThe (start, end) offset the table directive was found in the .feature file.
position: LineColThe (line, col) position the table directive was found in the .feature file.
Implementations